You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by se...@apache.org on 2012/03/22 22:27:47 UTC

svn commit: r1304077 - /commons/proper/io/trunk/src/main/java/org/apache/commons/io/IOUtils.java

Author: sebb
Date: Thu Mar 22 21:27:47 2012
New Revision: 1304077

URL: http://svn.apache.org/viewvc?rev=1304077&view=rev
Log:
Javadoc - rename offset as that is usually used for destination buffer

Modified:
    commons/proper/io/trunk/src/main/java/org/apache/commons/io/IOUtils.java

Modified: commons/proper/io/trunk/src/main/java/org/apache/commons/io/IOUtils.java
URL: http://svn.apache.org/viewvc/commons/proper/io/trunk/src/main/java/org/apache/commons/io/IOUtils.java?rev=1304077&r1=1304076&r2=1304077&view=diff
==============================================================================
--- commons/proper/io/trunk/src/main/java/org/apache/commons/io/IOUtils.java (original)
+++ commons/proper/io/trunk/src/main/java/org/apache/commons/io/IOUtils.java Thu Mar 22 21:27:47 2012
@@ -1470,7 +1470,7 @@ public class IOUtils {
      * 
      * @param input  the <code>InputStream</code> to read from
      * @param output  the <code>OutputStream</code> to write to
      * @param offset : number of bytes to skip from input before copying
      *         -ve values are ignored
      * @param length : number of bytes to copy. -ve means all
      * @return the number of bytes copied
@@ -1478,10 +1478,10 @@ public class IOUtils {
      * @throws IOException if an I/O error occurs
      * @since 2.2
      */
-    public static long copyLarge(InputStream input, OutputStream output, final long offset, final long length)
+    public static long copyLarge(InputStream input, OutputStream output, final long inputOffset, final long length)
             throws IOException {
-        if (offset > 0) {
-            skipFully(input, offset);
+        if (inputOffset > 0) {
+            skipFully(input, inputOffset);
         }
         if (length == 0) {
             return 0;
@@ -1620,7 +1620,7 @@ public class IOUtils {
      * 
      * @param input  the <code>Reader</code> to read from
      * @param output  the <code>Writer</code> to write to
      * @param offset : number of chars to skip from input before copying
      *         -ve values are ignored
      * @param length : number of chars to copy. -ve means all
      * @return the number of chars copied
@@ -1628,10 +1628,10 @@ public class IOUtils {
      * @throws IOException if an I/O error occurs
      * @since 2.2
      */
-    public static long copyLarge(Reader input, Writer output, final long offset, final long length)
+    public static long copyLarge(Reader input, Writer output, final long inputOffset, final long length)
  throws IOException {
-        if (offset > 0) {
-            skipFully(input, offset);
+        if (inputOffset > 0) {
+            skipFully(input, inputOffset);
         }
         if (length == 0) {
             return 0;
@@ -1470,7 +1470,7 @@ public class IOUtils {
      * @param input  the <code>InputStream</code> to read from
      * @param output  the <code>OutputStream</code> to write to
-     * @param offset : number of bytes to skip from input before copying
+     * @param inputOffset : number of bytes to skip from input before copying
      *         -ve values are ignored
      * @param length : number of bytes to copy. -ve means all
@@ -1620,7 +1620,7 @@ public class IOUtils {
      * @param input  the <code>Reader</code> to read from
      * @param output  the <code>Writer</code> to write to
-     * @param offset : number of chars to skip from input before copying
+     * @param inputOffset : number of chars to skip from input before copying
      *         -ve values are ignored
      * @param length : number of chars to copy. -ve means all